CommerceCapabilityCode class final

A Restage-defined capability code.

Unknown values are preserved for forward compatibility. Applications and provider adapters must not use this type as a namespace for provider codes.

Constructors

CommerceCapabilityCode(String value)
factory

Properties

hashCode int
The hash code for this object.
no setteroverride
isKnown bool
Whether this SDK recognizes value.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value String
The normalized Restage code.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

purchase → const CommerceCapabilityCode
Initiating a purchase for a logical offer.
purchaserStateRead → const CommerceCapabilityCode
Reading the current Restage purchaser state.
restore → const CommerceCapabilityCode
Restoring purchases through the configured commerce authority.