CommerceOfferId class final
An application- or Restage-defined logical offer selector.
It is not a raw provider product ID, offer token or identifier, promo code, receipt, or provider evidence.
Constructors
- CommerceOfferId(String value)
-
factory
Properties
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override