Config.allValues constructor
const
Config.allValues()
Selects every finite value of the annotated bool or enum property.
Implementation
const Config.allValues() : this(allValues: true);
Selects every finite value of the annotated bool or enum property.
const Config.allValues() : this(allValues: true);