CommerceAvailability class final
Whether a commerce capability can currently be requested.
- Inheritance
-
- Object
- CommerceResponse
- CommerceAvailability
Properties
- available → bool
-
final
- capability → CommerceCapabilityCode
-
final
- failureCode → CommerceFailureCode?
-
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- offerId → CommerceOfferId?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override