CommerceCapabilityCode class final
A Restage-defined capability code.
Unknown values are preserved for forward compatibility. Applications and provider adapters must not use this type as a namespace for provider codes.
Constructors
- CommerceCapabilityCode(String value)
-
factory
Properties
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Constants
- purchase → const CommerceCapabilityCode
- Initiating a purchase for a logical offer.
- purchaserStateRead → const CommerceCapabilityCode
- Reading the current Restage purchaser state.
- restore → const CommerceCapabilityCode
- Restoring purchases through the configured commerce authority.