Config.maxStories constructor
const
Config.maxStories(
- int maxStories
Configures the maximum generated story count for one widget.
The package default is 32. An override must be greater than zero and no greater than the absolute ceiling of 256.
Implementation
const Config.maxStories(int maxStories) : this(maxStories: maxStories);